@@ -156,8 +156,9 @@ class KafkaAPI():
             return None
 
     @staticmethod
-    def createConsumerFromEnvs() -> Consumer:
-        groupId = os.environ['KAFKA_GROUP_ID']
+    def createConsumerFromEnvs(groupId=None) -> Consumer:
+        if groupId is None:
+            groupId = os.environ['KAFKA_GROUP_ID']
         authType = os.environ['KAFKA_SASL_MECHANISM']  # GSSAPI(Kerberos) | NOSASL(Normal) | PLAIN(Password)
         severs = os.environ['KAFKA_HOST_URL']
         debug = os.environ['KAFKA_DEBUG'].lower() == 'true'
